Enum tree_sitter_graph::ast::Expression [−][src]
pub enum Expression {
FalseLiteral,
NullLiteral,
TrueLiteral,
IntegerConstant(IntegerConstant),
StringConstant(StringConstant),
List(ListComprehension),
Set(SetComprehension),
Capture(Capture),
Variable(Variable),
Call(Call),
RegexCapture(RegexCapture),
}Expand description
An expression that can appear in a graph DSL file
Variants
IntegerConstant(IntegerConstant)Tuple Fields of IntegerConstant
StringConstant(StringConstant)Tuple Fields of StringConstant
List(ListComprehension)Tuple Fields of List
Set(SetComprehension)Tuple Fields of Set
Capture(Capture)Tuple Fields of Capture
0: CaptureVariable(Variable)Tuple Fields of Variable
0: VariableCall(Call)Tuple Fields of Call
0: CallRegexCapture(RegexCapture)Tuple Fields of RegexCapture
0: RegexCaptureTrait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.