Struct tree_sitter_graph::ast::AddEdgeAttribute [−][src]
pub struct AddEdgeAttribute {
pub source: Expression,
pub sink: Expression,
pub attributes: Vec<Attribute>,
pub location: Location,
}Expand description
An attr statement that adds an attribute to an edge
Fields
source: Expressionsink: Expressionattributes: Vec<Attribute>location: LocationTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.