Struct tree_sitter_graph::ast::AddGraphNodeAttribute [−][src]
pub struct AddGraphNodeAttribute {
pub node: Expression,
pub attributes: Vec<Attribute>,
pub location: Location,
}Expand description
An attr statement that adds an attribute to a graph node
Fields
node: Expressionattributes: Vec<Attribute>location: LocationTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.