Struct tree_sitter_graph::ast::CreateGraphNode [−][src]
A node statement that creates a new graph node
Fields
node: Variablelocation: LocationTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.