Struct tree_sitter_graph::ast::DeclareImmutable [−][src]
pub struct DeclareImmutable {
pub variable: Variable,
pub value: Expression,
pub location: Location,
}Expand description
A let statement that declares a new immutable variable
Fields
variable: Variablevalue: Expressionlocation: LocationTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.