Struct tree_sitter_graph::ast::DeclareMutable [−][src]
pub struct DeclareMutable {
pub variable: Variable,
pub value: Expression,
pub location: Location,
}Expand description
A var statement that declares a new mutable variable
Fields
variable: Variablevalue: Expressionlocation: LocationTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.