Struct tree_sitter_graph::ast::File [−][src]
A graph DSL file
Fields
language: Languagestanzas: Vec<Stanza>The list of stanzas in the file
Implementations
Executes this graph DSL file against a source file. You must provide the parsed syntax
tree (tree) as well as the source text that it was parsed from (source). You also
provide the set of functions and global variables that are available during execution.