Struct tree_sitter_graph::ast::RegexCapture [−][src]
pub struct RegexCapture {
pub match_index: usize,
}Expand description
A reference to one of the regex captures in a scan statement
Fields
match_index: usizeTrait Implementations
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.