Enum tree_sitter_graph::graph::Value [−][src]
pub enum Value {
Null,
Boolean(bool),
Integer(u32),
String(String),
List(Vec<Value>),
Set(BTreeSet<Value>),
SyntaxNode(SyntaxNodeRef),
GraphNode(GraphNodeRef),
}Expand description
The value of an attribute
Variants
Boolean(bool)Tuple Fields of Boolean
0: boolInteger(u32)Tuple Fields of Integer
0: u32String(String)Tuple Fields of String
0: StringSyntaxNode(SyntaxNodeRef)Tuple Fields of SyntaxNode
GraphNode(GraphNodeRef)Tuple Fields of GraphNode
0: GraphNodeRefImplementations
Coerces this value into an integer, returning an error if it’s some other type of value.
Coerces this value into a string, returning an error if it’s some other type of value.
pub fn into_syntax_node<'a, 'tree>(
self,
graph: &'a Graph<'tree>
) -> Result<&'a Node<'tree>, ExecutionError>
pub fn into_syntax_node<'a, 'tree>(
self,
graph: &'a Graph<'tree>
) -> Result<&'a Node<'tree>, ExecutionError>
Coerces this value into a syntax node reference, returning an error if it’s some other type of value.