Struct tree_sitter_graph::graph::Attributes [−][src]
pub struct Attributes { /* fields omitted */ }Expand description
A set of attributes associated with a graph node or edge
Implementations
Creates a new, empty set of attributes.
Adds an attribute to this attribute set. If there was already an attribute with the same
name, replaces its value and returns Err.
Returns the value of a particular attribute, if it exists.
pub fn display_with<'a>(
&'a self,
ctx: &'a Context,
graph: &'a Graph<'_>
) -> impl Display + 'a
pub fn display_with<'a>(
&'a self,
ctx: &'a Context,
graph: &'a Graph<'_>
) -> impl Display + 'a
fmt::Displays the contents of this attribute set.