Struct tree_sitter_graph::graph::Graph [−][src]
pub struct Graph<'tree> { /* fields omitted */ }Expand description
A graph produced by executing a graph DSL file. Graphs include a lifetime parameter to ensure that they don’t outlive the tree-sitter syntax tree that they are generated from.
Implementations
Adds a syntax node to the graph, returning a graph DSL reference to it.
The graph won’t contain every syntax node in the parsed syntax tree; it will only contain those nodes that are referenced at some point during the execution of the graph DSL file.
Adds a new graph node to the graph, returning a graph DSL reference to it.
fmt::Displays the contents of this graph.