Struct tree_sitter_graph::graph::GraphNode [−][src]
pub struct GraphNode {
pub attributes: Attributes,
// some fields omitted
}Expand description
A node in a graph
Fields
attributes: AttributesThe set of attributes associated with this graph node
Implementations
Adds an edge to this node. There can be at most one edge connecting any two graph nodes;
the result indicates whether the edge is new (Ok) or already existed (Err). In either
case, you also get a mutable reference to the Edge instance for the edge.
Returns a reference to an outgoing edge from this node, if it exists.
Returns a mutable reference to an outgoing edge from this node, if it exists.